@@ -29,7 +29,6 @@ import time
 import sys
 
 import six
-from six.moves import range
 
 import scalyr_agent.scalyr_logging as scalyr_logging
 import scalyr_agent.util as scalyr_util
@@ -1026,6 +1025,18 @@ class CopyingManager(StoppableThread, LogWatcher):
             for entry in self.__log_matchers:
                 result.log_matchers.append(entry.generate_status())
 
+            if self.__last_attempt_time:
+                result.health_check_result = "Good"
+                if (
+                    time.time()
+                    > self.__last_attempt_time
+                    + self.__config.healthy_max_time_since_last_copy_attempt
+                ):
+                    result.health_check_result = (
+                        "Failed, max time since last copy attempt (%s seconds) exceeded"
+                        % self.__config.healthy_max_time_since_last_copy_attempt
+                    )
+
         finally:
             self.__lock.release()
         if warn_on_rate_limit:
@@ -1230,6 +1241,9 @@ class CopyingManager(StoppableThread, LogWatcher):
 
         # We have to iterate over all of the LogFileProcessors, getting bytes from them.  We also have to
         # collect all of the callback that they give us and wrap it into one massive one.
+        # all_callbacks maps the callback for a processor keyed by the processor's unique id.  We use the unique id to
+        # provide a stable mapping, even if the list of log processors changes between now and when we process
+        # the response (which it may if pipelining is turned on and we process the other request's response).
         all_callbacks = {}
         logs_processed = 0
 
@@ -1256,9 +1270,8 @@ class CopyingManager(StoppableThread, LogWatcher):
 
         while not buffer_filled and logs_processed < len(self.__log_processors):
             # Iterate, getting bytes from each LogFileProcessor until we are full.
-            (callback, buffer_filled) = self.__log_processors[
-                current_processor
-            ].perform_processing(add_events_request)
+            processor = self.__log_processors[current_processor]
+            (callback, buffer_filled) = processor.perform_processing(add_events_request)
 
             # A callback of None indicates there was some error reading the log.  Just retry again later.
             if callback is None:
@@ -1269,7 +1282,7 @@ class CopyingManager(StoppableThread, LogWatcher):
                 self.total_read_time += end_time - start_time
                 return None
 
-            all_callbacks[current_processor] = callback
+            all_callbacks[processor.unique_id] = callback
             logs_processed += 1
 
             # Advance if the buffer if not filled.  Also, even if it is filled, if we are on the first
@@ -1309,13 +1322,14 @@ class CopyingManager(StoppableThread, LogWatcher):
 
             total_bytes_copied = 0
 
-            for i in range(0, len(processor_list)):
+            for processor in processor_list:
                 # Iterate over all the processors, seeing if we had a callback for that particular processor.
-                processor = processor_list[i]
-                if i in all_callbacks:
+                if processor.unique_id in all_callbacks:
                     # noinspection PyCallingNonCallable
                     # If we did have a callback for that processor, report the status and see if we callback is done.
-                    (closed_processor, bytes_copied) = all_callbacks[i](result)
+                    (closed_processor, bytes_copied) = all_callbacks[
+                        processor.unique_id
+                    ](result)
                     keep_it = not closed_processor
                     total_bytes_copied += bytes_copied
                 else:
